From 15797e8153fd90e6f457cc3bcd0237fbfd4491d4 Mon Sep 17 00:00:00 2001
From: Aditya Vidyadhar Kamath <Aditya.Kamath1@ibm.com>
Date: Tue, 25 Oct 2022 01:35:33 -0500
Subject: [PATCH] Fix multi thread debug bug in AIX

In the recent commit 98ed24fb35d89eb20179edf6c12f599c7a9e228e made by Mr. Tom there is a change in aix-thread.c file that changes

 static_cast <aix_thread_info *> in gdb to gdb::checked_static_cast <aix_thread_info *>

AIX folks using the latest version will not be able to debug multi thread programs as a result of it.

The error in AIX is as follows:-

internal-error: checked_static_cast: Assertion 'result != nullptr' failed.

The reason is that the first thread in a multi threaded program will not have a prev.

Hence we need to add this check.

The future threads if any will handle the change gdb::checked_static_cast with ease after this condition is checked.
---
 gdb/aix-thread.c | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/gdb/aix-thread.c b/gdb/aix-thread.c
index e556c153576..b2dabd242fc 100644
--- a/gdb/aix-thread.c
+++ b/gdb/aix-thread.c
@@ -90,6 +90,9 @@ struct aix_thread_info : public private_thread_info
 static aix_thread_info *
 get_aix_thread_info (thread_info *thread)
 {
+  if (thread->priv == NULL)
+    return NULL;
+
   return gdb::checked_static_cast<aix_thread_info *> (thread->priv.get ());
 }
 
-- 
2.31.1

